Specs
=====

This section contains detailed specification documents for
different features inside Karbor.

Approved Specs
--------------

.. toctree::
    :maxdepth: 1

    add-db-manage-purge
    api-service
    bank-plugin-lease
    checkpoint-metadata
    checkpoint-scheduled-clean
    cinder-volume-snapshot-plugin
    file-system-bank
    instances-extra-info
    instances-parameters
    manila-share-snapshot-plugins
    operation-engine/operation_engine_design
    pluggable_protection_provider
    protection-service/protection-service
    protection-service/restore-design-spec
    refactor_clients
    remove_heat
    restore-resource-status
    s3-bank
    trove-database-backup-plugins
    operation-log-api

Spec Template
-------------
.. toctree::
    :maxdepth: 1

    skeleton
    template


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
